pub struct BorrowedChildName { /* private fields */ }Expand description
Like ChildName, except it holds a string slice rather than an allocated string. For
example, the [Moniker] API uses this to return path segments without making an allocation.
Implementations
Sourceimpl BorrowedChildName
impl BorrowedChildName
Sourcepub fn parse<S: AsRef<str> + ?Sized>(s: &S) -> Result<&Self, MonikerError>
pub fn parse<S: AsRef<str> + ?Sized>(s: &S) -> Result<&Self, MonikerError>
Parses a ChildName from a string.
Input strings should be of the format [collection:]name, e.g. foo or biz:foo.
pub fn name(&self) -> &BorrowedLongName
pub fn collection(&self) -> Option<&BorrowedName>